# User Preference

##

Type: enum (of string) Default: "Linux"

#### Must be one of:

- "Windows"
- "Mac"
- "Linux"

##

Type: array of enum (of string) Default: ['white', 'blue']

#### Each item of this array must be:

Type: enum (of string)

#### Must be one of:

- "green"
- "blue"
- "orange"
- "red"
- "white"
- "black"

##

Type: integer Default: 2

Value must be greater or equal to `0` and lesser or equal to `2`